Package: RNAmodR.AlkAnilineSeq
Type: Package
Title: Detection of m7G, m3C and D modification by AlkAnilineSeq
Version: 1.26.0
Date: 2025-09-23
Authors@R: c(person("Felix G.M.", 
                    "Ernst", 
                    email = "felix.gm.ernst@outlook.com", 
                    role = c("aut", "cre"),
                    comment = c(ORCID = "0000-0001-5064-0928")),
             person("Denis L.J.", 
                    "Lafontaine", 
                    email = "denis.lafontaine@ulb.ac.be", 
                    role = c("ctb", "fnd")))
Description: RNAmodR.AlkAnilineSeq implements the detection of m7G, m3C and D 
    modifications on RNA from experimental data generated with the 
    AlkAnilineSeq protocol. The package builds on the core functionality of the 
    RNAmodR package to detect specific patterns of the modifications in high 
    throughput sequencing data.
biocViews: Software, WorkflowStep, Visualization, Sequencing
License: Artistic-2.0
Encoding: UTF-8
LazyData: false
Depends: R (>= 4.0), RNAmodR (>= 1.5.3)
Imports: methods, S4Vectors, IRanges, BiocGenerics, GenomicRanges, Gviz
Suggests: BiocStyle, knitr, rmarkdown, testthat, rtracklayer,
        Biostrings, Seqinfo, RNAmodR.Data
Collate: 'RNAmodR.AlkAnilineSeq.R' 'Modifier-AlkAnilineSeq-class.R'
        'Modifier-AlkAnilineSeq-viz.R'
VignetteBuilder: knitr
RoxygenNote: 7.3.3
BugReports: https://github.com/FelixErnst/RNAmodR.AlkAnilineSeq/issues
URL: https://github.com/FelixErnst/RNAmodR.AlkAnilineSeq
git_url: https://git.bioconductor.org/packages/RNAmodR.AlkAnilineSeq
git_branch: RELEASE_3_23
git_last_commit: 9eb70f5
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:18:15 UTC; biocbuild
Author: Felix G.M. Ernst [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-5064-0928>),
  Denis L.J. Lafontaine [ctb, fnd]
Maintainer: Felix G.M. Ernst <felix.gm.ernst@outlook.com>
