# Generated by roxygen2: do not edit by hand

export(ModAlkAnilineSeq)
export(ModSetAlkAnilineSeq)
exportClasses(ModAlkAnilineSeq)
exportClasses(ModSetAlkAnilineSeq)
exportMethods("settings<-")
exportMethods(aggregateData)
exportMethods(findMod)
exportMethods(getDataTrack)
exportMethods(plotData)
exportMethods(plotDataByCoord)
import(BiocGenerics)
import(GenomicRanges)
import(Gviz)
import(IRanges)
import(RNAmodR)
import(S4Vectors)
import(methods)
importMethodsFrom(RNAmodR,aggregate)
importMethodsFrom(RNAmodR,modify)
importMethodsFrom(RNAmodR,plotData)
importMethodsFrom(RNAmodR,plotDataByCoord)
importMethodsFrom(RNAmodR,settings)
